Installation
------------
Install from ``conda-forge``:

.. code:: sh

   conda install -c conda-forge xarrera

or from ``PyPI``:

.. code:: sh

   python -m pip install xarrera

or from source, either directly from github:

.. code:: sh

   python -m pip install git+https://github.com/javgat/xarrera

or from a local copy:

.. code:: sh

   git clone https://github.com/javgat/xarrera
   python -m pip install ./xarrera

Dependencies
~~~~~~~~~~~~

xarrera depends on:

- numpy
- xarray

See xarrera's `requirements.txt`_ for minimum versions.

.. _requirements.txt: https://github.com/javgat/xarrera/blob/main/requirements.txt
